@@ -13,10 +13,10 @@ def sol_ode(model, var0, t, param):
     
     Args:
         model (callable(var,t,param)): The function computes the derivative of y at t.
-        var0 (array): Initial condition on var.
+        var0 (array): Initial condition of var.
         t (array):  A sequence of time points for which to solve for var. The initial
                     value point should be the first element of this sequence.
-        param (array): Parameters of the model.
+        param (array): model parameters.
 
     Returns:
         ar (array): Array containing the value of var for each desired time in t, with the initial value var0 in the first row
